@@ -4,6 +4,7 @@
 """ Transform an Incoming Mention Event """
 
 
+from typing import Optional
 from pprint import pformat
 
 from baseblock import BaseObject, Enforcer
@@ -33,6 +34,11 @@ class TransformIncomingEvent(BaseObject):
             7-Oct-2022
             craigtrim@gmail.com
             *   refactored into 'slackbot-helper'
+        Updated:
+            12-Feb-2023
+            craigtrim@gmail.com
+            *   capture thread-ts in normalized event
+                https://github.com/craigtrim/slackbot-helper/issues/11
         """
         BaseObject.__init__(self, __name__)
 
@@ -50,11 +56,17 @@ class TransformIncomingEvent(BaseObject):
             dict: validated slack event
         """
 
+        # # slackbot-helper/issues/11
+        def get_thread_ts() -> Optional[float]:
+            if 'thread_ts' in d_event:
+                return float(d_event['thread_ts'])
+
         d = {
             'type': d_event['type'],
             'text': d_event['text'],
             'user': d_event['user'],
             'ts': float(d_event['ts']),
+            'thread_ts': get_thread_ts(),
             'team': d_event['team'],
             'channel': d_event['channel'],
         }
@@ -68,6 +80,7 @@ class TransformIncomingEvent(BaseObject):
             Enforcer.is_str(d['text'])
             Enforcer.is_str(d['user'])
             Enforcer.is_float(d['ts'])
+            Enforcer.is_optional_float(d['thread_ts'])
             Enforcer.is_str(d['team'])
             Enforcer.is_str(d['channel'])
             if 'blocks' in d:
